@@ -6,7 +6,7 @@ urlpatterns = patterns('',
 
     url(r'^register/$', 'oppia.profile.views.register', name="profile_register"),
     url(r'^register/thanks/$', TemplateView.as_view(template_name="oppia/thanks.html"), name="profile_register_thanks"),
-    url(r'^login/$', 'django.contrib.auth.views.login', {'template_name': 'oppia/login.html',}),
+    url(r'^login/$', 'oppia.profile.views.login_view', name="profile_login"),
     url(r'^logout/$', 'django.contrib.auth.views.logout', {'template_name': 'oppia/logout.html',}),
     url(r'^setlang/$', 'django.views.i18n.set_language', name="profile_set_language"),
     url(r'^reset/$', 'oppia.profile.views.reset', name="profile_reset"),
