@@ -6,6 +6,8 @@ import os
 import oppia
 import tablib
 
+from dateutil.relativedelta import relativedelta
+
 from django import forms
 from django.conf import settings
 from django.contrib.auth import (authenticate, logout, views)
@@ -19,7 +21,7 @@ from django.shortcuts import render,render_to_response
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 
-from oppia.forms import UploadCourseForm, ScheduleForm
+from oppia.forms import UploadCourseForm, ScheduleForm, DateRangeForm, DateRangeIntervalForm
 from oppia.forms import ActivityScheduleForm, CohortForm
 from oppia.models import Course, Tracker, Tag, CourseTag, Schedule
 from oppia.models import ActivitySchedule, Activity, Cohort, Participant, Points
@@ -28,21 +30,66 @@ from oppia.quiz.models import Quiz, QuizAttempt, QuizAttemptResponse
 from uploader import handle_uploaded_file
 
 def server_view(request):
-    return render_to_response('oppia/server.html',  {'settings': settings}, content_type="application/json", context_instance=RequestContext(request))
+    return render_to_response('oppia/server.html',  
+                              {'settings': settings}, 
+                              content_type="application/json", 
+                              context_instance=RequestContext(request))
 
 def home_view(request):
     activity = []
     if request.user.is_authenticated():
-        startdate = datetime.datetime.now()
-        for i in range(31,-1,-1):
-            temp = startdate - datetime.timedelta(days=i)
-            day = temp.strftime("%d")
-            month = temp.strftime("%m")
-            year = temp.strftime("%Y")
-            count = Tracker.objects.filter(course__isnull=False, course__is_draft=False, user__is_staff=False, course__is_archived=False,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
-            activity.append([temp.strftime("%d %b %Y"),count])
+        start_date = datetime.datetime.now() - datetime.timedelta(days=31)
+        end_date = datetime.datetime.now()
+        interval = 'days'
+        if request.method == 'POST':
+            form = DateRangeIntervalForm(request.POST)
+            if form.is_valid():
+                start_date = form.cleaned_data.get("start_date")  
+                start_date = datetime.datetime.strptime(start_date,"%Y-%m-%d")
+                end_date = form.cleaned_data.get("end_date")
+                end_date = datetime.datetime.strptime(end_date,"%Y-%m-%d")   
+                interval =  form.cleaned_data.get("interval")          
+        else:
+            data = {}
+            data['start_date'] = start_date
+            data['end_date'] = end_date
+            data['interval'] = interval
+            form = DateRangeIntervalForm(initial=data)
+        
+        if interval == 'days':
+            no_days = (end_date-start_date).days + 1
+            
+            for i in range(0,no_days,+1):
+                temp = start_date + datetime.timedelta(days=i)
+                day = temp.strftime("%d")
+                month = temp.strftime("%m")
+                year = temp.strftime("%Y")
+                count = Tracker.objects.filter(course__isnull=False, course__is_draft=False, user__is_staff=False, course__is_archived=False,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
+                activity.append([temp.strftime("%d %b %Y"),count])
+        else:
+            delta = relativedelta(months=+1)
+            
+            no_months = 0
+            tmp_date = start_date
+            while tmp_date <= end_date:
+                print tmp_date
+                tmp_date += delta
+                no_months += 1
+                
+            for i in range(0,no_months,+1):
+                temp = start_date + relativedelta(months=+i)
+                month = temp.strftime("%m")
+                year = temp.strftime("%Y")
+                count = Tracker.objects.filter(course__isnull=False, course__is_draft=False, user__is_staff=False, course__is_archived=False,tracker_date__month=month,tracker_date__year=year).count()
+                activity.append([temp.strftime("%b %Y"),count])
+    else:
+        form = None
     leaderboard = Points.get_leaderboard(10)
-    return render_to_response('oppia/home.html',{'recent_activity':activity, 'leaderboard':leaderboard}, context_instance=RequestContext(request))
+    return render_to_response('oppia/home.html',
+                              {'form': form,
+                               'recent_activity':activity, 
+                               'leaderboard':leaderboard}, 
+                              context_instance=RequestContext(request))
 
 def course_view(request):
     if request.user.is_staff:
@@ -60,7 +107,27 @@ def course_view(request):
             
             count = Tracker.objects.filter(course = course, user__is_staff=False, tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
             course.activity.append([temp.strftime("%d %b %Y"),count])  
-    return render_to_response('oppia/course/course.html',{'course_list': course_list}, context_instance=RequestContext(request))
+    tag_list = Tag.objects.all().order_by('name')
+    return render_to_response('oppia/course/course.html',{'course_list': course_list, 'tag_list': tag_list}, context_instance=RequestContext(request))
+
+def tag_courses_view(request, id):
+    if request.user.is_staff:
+        course_list = Course.objects.filter(is_archived=False, coursetag__tag_id=id).order_by('title')
+    else:
+        course_list = Course.objects.filter(is_draft=False,is_archived=False, coursetag__tag_id=id).order_by('title')   
+    startdate = datetime.datetime.now()
+    for course in course_list:
+        course.activity = []
+        for i in range(7,-1,-1):
+            temp = startdate - datetime.timedelta(days=i)
+            day = temp.strftime("%d")
+            month = temp.strftime("%m")
+            year = temp.strftime("%Y")
+            
+            count = Tracker.objects.filter(course = course, user__is_staff=False, tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).count()
+            course.activity.append([temp.strftime("%d %b %Y"),count])  
+    tag_list = Tag.objects.all().order_by('name')
+    return render_to_response('oppia/course/course.html',{'course_list': course_list, 'tag_list': tag_list, 'current_tag': id}, context_instance=RequestContext(request))
 
        
 def terms_view(request):
@@ -109,33 +176,106 @@ def upload(request):
 
 def recent_activity(request,id):
     course = check_can_view(request, id)
+    
+    start_date = datetime.datetime.now() - datetime.timedelta(days=31)
+    end_date = datetime.datetime.now()
+    interval = 'days'
+    
+    if request.method == 'POST':
+        form = DateRangeIntervalForm(request.POST)
+        if form.is_valid():
+            start_date = form.cleaned_data.get("start_date")  
+            start_date = datetime.datetime.strptime(start_date,"%Y-%m-%d")
+            end_date = form.cleaned_data.get("end_date")
+            end_date = datetime.datetime.strptime(end_date,"%Y-%m-%d") 
+            interval =  form.cleaned_data.get("interval")               
+    else:
+        data = {}
+        data['start_date'] = start_date
+        data['end_date'] = end_date
+        data['interval'] = interval
+        form = DateRangeIntervalForm(initial=data)
+    
     dates = []
-    startdate = datetime.datetime.now()
-    for i in range(31,-1,-1):
-        temp = startdate - datetime.timedelta(days=i)
-        day = temp.strftime("%d")
-        month = temp.strftime("%m")
-        year = temp.strftime("%Y")
-        count_objs = Tracker.objects.filter(course=course,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).values('type').annotate(total=Count('type'))
-        count_activity = {'page':0, 'quiz':0, 'media':0, 'resource':0, 'monitor': 0, 'total':0}
-        for co in count_objs:
-            if co['type'] in count_activity:
-                count_activity[co['type']] = count_activity[co['type']] + co['total']
-                count_activity['total'] = count_activity['total'] + co['total']
-            else:
-                count_activity[co['type']] = 0
-                count_activity[co['type']] = count_activity[co['type']] + co['total']
-                count_activity['total'] = count_activity['total'] + co['total']
+    if interval == 'days':
+        no_days = (end_date-start_date).days + 1
+        
+        for i in range(0,no_days,+1):
+            temp = start_date + datetime.timedelta(days=i)
+            day = temp.strftime("%d")
+            month = temp.strftime("%m")
+            year = temp.strftime("%Y")
+            count_objs = Tracker.objects.filter(course=course,tracker_date__day=day,tracker_date__month=month,tracker_date__year=year).values('type').annotate(total=Count('type'))
+            count_activity = {'page':0, 'quiz':0, 'media':0, 'resource':0, 'monitor': 0, 'total':0}
+            for co in count_objs:
+                if co['type'] in count_activity:
+                    count_activity[co['type']] = count_activity[co['type']] + co['total']
+                    count_activity['total'] = count_activity['total'] + co['total']
+                else:
+                    count_activity[co['type']] = 0
+                    count_activity[co['type']] = count_activity[co['type']] + co['total']
+                    count_activity['total'] = count_activity['total'] + co['total']
+            
+            dates.append([temp.strftime("%d %b %y"),count_activity])
+    else:
+        delta = relativedelta(months=+1)  
+        no_months = 0
+        tmp_date = start_date
+        while tmp_date <= end_date:
+            print tmp_date
+            tmp_date += delta
+            no_months += 1
+            
+        for i in range(0,no_months,+1):
+            temp = start_date + relativedelta(months=+i)
+            month = temp.strftime("%m")
+            year = temp.strftime("%Y")
+            count_objs = Tracker.objects.filter(course=course,tracker_date__month=month,tracker_date__year=year).values('type').annotate(total=Count('type'))
+            count_activity = {'page':0, 'quiz':0, 'media':0, 'resource':0, 'monitor': 0, 'total':0}
+            for co in count_objs:
+                if co['type'] in count_activity:
+                    count_activity[co['type']] = count_activity[co['type']] + co['total']
+                    count_activity['total'] = count_activity['total'] + co['total']
+                else:
+                    count_activity[co['type']] = 0
+                    count_activity[co['type']] = count_activity[co['type']] + co['total']
+                    count_activity['total'] = count_activity['total'] + co['total']
+            
+            dates.append([temp.strftime("%b %y"),count_activity])
+        
         
-        dates.append([temp.strftime("%d %b %y"),count_activity])
     leaderboard = Points.get_leaderboard(10, course)
     nav = get_nav(course,request.user)
-    return render_to_response('oppia/course/activity.html',{'course': course,'nav': nav, 'data':dates, 'leaderboard':leaderboard}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/activity.html',
+                              {'course': course,
+                               'form': form,
+                                'nav': nav, 
+                                'data':dates, 
+                                'leaderboard':leaderboard}, 
+                              context_instance=RequestContext(request))
 
 def recent_activity_detail(request,id):
     course = check_owner(request,id)
         
-    trackers = Tracker.objects.filter(course=course).order_by('-tracker_date')
+    start_date = datetime.datetime.now() - datetime.timedelta(days=31)
+    end_date = datetime.datetime.now()
+    if request.method == 'POST':
+        form = DateRangeForm(request.POST)
+        if form.is_valid():
+            start_date = form.cleaned_data.get("start_date")  
+            start_date = datetime.datetime.strptime(start_date,"%Y-%m-%d")
+            end_date = form.cleaned_data.get("end_date")
+            end_date = datetime.datetime.strptime(end_date,"%Y-%m-%d") 
+            trackers = Tracker.objects.filter(course=course,tracker_date__gte=start_date, tracker_date__lte=end_date).order_by('-tracker_date')
+        else:
+            trackers = Tracker.objects.filter(course=course).order_by('-tracker_date')             
+    else:
+        data = {}
+        data['start_date'] = start_date
+        data['end_date'] = end_date
+        form = DateRangeForm(initial=data)
+        trackers = Tracker.objects.filter(course=course).order_by('-tracker_date')
+        
     paginator = Paginator(trackers, 25)
     # Make sure page request is an int. If not, deliver first page.
     try:
@@ -160,7 +300,12 @@ def recent_activity_detail(request,id):
         tracks = paginator.page(paginator.num_pages)
     
     nav = get_nav(course, request.user) 
-    return render_to_response('oppia/course/activity-detail.html',{'course': course,'nav': nav, 'page':tracks,}, context_instance=RequestContext(request))
+    return render_to_response('oppia/course/activity-detail.html',
+                              {'course': course,
+                               'form': form,
+                               'nav': nav, 
+                               'page':tracks,}, 
+                              context_instance=RequestContext(request))
 
 
 def export_tracker_detail(request,id):
